@@ -1,6 +1,6 @@
 package Crypt::Affine;
 
-$Crypt::Affile::VERSION = '0.06';
+$Crypt::Affile::VERSION = '0.07';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Crypt::Affine - Interface to the Affine cipher.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
@@ -154,9 +154,9 @@ sub _prepare {
 
     if (defined($self->{'source'}) && (-e $self->{'source'})) {
         local undef $/;
-        open(IN, $self->{'source'});
-        $_data = <IN>;
-        close(IN);
+        open(my $IN, $self->{'source'});
+        $_data = <$IN>;
+        close($IN);
 
         chomp $_data;
         @data = split /\,/,$_data;
@@ -278,7 +278,7 @@ L<http://search.cpan.org/dist/Crypt-Affine/>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright (C) 2011 - 2014 Mohammad S Anwar.
+Copyright (C) 2011 - 2015 Mohammad S Anwar.
 
 This  program  is  free software; you can redistribute it and/or modify it under
 the  terms  of the the Artistic License (2.0). You may obtain a copy of the full
